$calendarBackground = #fff
$calendarBorderColor = #eceef1

$monthForeground = #5a6171
$monthBackground = #eceef1

$weekdaysBackground = #eceef1
$weekdaysForeground = #5a6171

$dayForeground = #484848
$dayHoverBackground = #e2e2e2

$todayColor = #bbb

$selectedDayBackground = #FF5A5F
$selectedDayForeground = #fff

$noCalendarBorder = true
@require "../flatpickr"

span.flatpickr-day.selected
	font-weight bold