$calendarBackground = #fff
$calendarBorderColor = alpha(#484848, 0.1)

$monthForeground = #fff
$monthBackground = #FFB866

$weekdaysBackground = #FFB866

$dayForeground = #484848
$dayHoverBackground = #e2e2e2

$todayColor = #bbb

$selectedDayBackground = #FFB866
$selectedDayForeground = #fff

$noCalendarBorder = true
@require "../flatpickr"
