@require "./_vars.styl"

span.flatpickr-weekday
  display: inline-block;
  width: 14.2857143%


span.flatpickr-day
  width: 14.2857143%;
  margin: 0 (($daysWidth - $daySize*7)/14)

@media screen and (min-width:unquote("0\0"))
  div.flatpickr-current-month
      padding-top: 0px !important
