$calendarBackground = #3f4458
$calendarBorderColor = darken(#3f4458, 50%)

$monthForeground = #fff
$monthBackground = #3f4458

$weekdaysBackground = transparent
$weekdaysForeground = #fff

$dayForeground = alpha(white, 0.95)
$dayHoverBackground = lighten($calendarBackground, 25%)

$todayColor = #eee
$today_fg_color = #3f4458

$selectedDayBackground = #80CBC4

@require "../flatpickr"
